#
# spec file for package libvlc-qt
#
# Copyright (c) 2013 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015 Packman Team <packman@links2linux.de>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


%define soname 0_10
%define _name   vlc-qt
%if 0%{?suse_version} == 1315 && 0%{?is_opensuse}
%define Leap_verSP 4210
%endif
%if 0%{?Leap_verSP} == 4210 || 0%{?suse_version} > 1315
%bcond_without qt5
%endif
Name:           libvlc-qt
Version:        0.10.0
Release:        6.14
Summary:        Qt and libvlc connector library
License:        LGPL-3.0+
Group:          System/Libraries
Url:            http://vlc-qt.tano.si/
Source:         https://github.com/ntadej/%{_name}/archive/%{version}/vlc-qt-%{version}.tar.gz
# PATCH-FIX-UPSTREAM libvlc-qt_qapplication.patch aloisio@gmx.com -- Fix 13.1 build.
Patch0:         %{name}_qapplication.patch
# PATCH-FIX-OPENSUSE libvlc-qt_no-date-time.patch svalx@svalx.net -- Fix file-contains-date-and-time warning for doxygen generated documentation.
Patch1:         %{name}_no-date-time.patch
BuildRequires:  cmake >= 2.8
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  pkg-config
BuildRequires:  vlc-devel
%if %{with qt5}
BuildRequires:  pkgconfig(Qt5Quick) >= 5.2
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2
%else
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtGui)
%endif

%description
VLC-Qt is a free library used to connect Qt and libvlc libraries.
It contains core classes for main media playback and also some GUI
classes for faster media player development.

%package -n %{name}%{soname}
Summary:        Qt and libvlc connector library
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n %{name}%{soname}
VLC-Qt is a free library used to connect Qt and libvlc libraries.
It contains core classes for main media playback and also some GUI
classes for faster media player development.

%package widgets%{soname}
Summary:        Qt and libvlc connector library
Provides:       %{name}-widgets = %{version}
Obsoletes:      %{name}-widgets < %{version}

%description widgets%{soname}
This package contains some widget classes for faster media player
development.

%if %{with qt5}
%package qml%{soname}
Summary:        Qt and libvlc connector library
Provides:       %{name}-qml = %{version}
Obsoletes:      %{name}-qml < %{version}

%description qml%{soname}
This package contains some QML classes for faster media player
development.
%endif

%package devel
Summary:        Include Files and Libraries Mandatory for Development
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       %{name}-widgets = %{version}

%description devel
The libvlc-qt-devel package contains libraries and header files for
developing applications that use libvlc-qt.

%package doc
Summary:        Dcoumentation for libvlc-qt
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
BuildArch:      noarch

%description doc
Doxygen generated documentation and help files for libvlc-qt.

%prep
%setup -q -n %{_name}-%{version}
%patch0 -p1
%patch1 -p0
%if !%{with qt5}
find . -type f -name 'CMakeLists.txt' | while read cmlists; do
    sed -i '/CMAKE_MINIMUM_REQUIRED/d;s/\(Qt4::\)/\1Qt/g' "$cmlists"
done
%endif

%build
%cmake \
%if %{with qt5}
  -DQT_VERSION=5
%else
  -DQT_VERSION=4 -DWITH_X11=ON
%endif
make %{?_smp_mflags}
doxygen doc/Doxyfile

%install
%cmake_install
%fdupes -s build/html

%post -n %{name}%{soname} -p /sbin/ldconfig

%postun -n %{name}%{soname} -p /sbin/ldconfig

%post -n %{name}-widgets%{soname} -p /sbin/ldconfig

%postun -n %{name}-widgets%{soname} -p /sbin/ldconfig

%if %{with qt5}
%post -n %{name}-qml%{soname} -p /sbin/ldconfig

%postun -n %{name}-qml%{soname} -p /sbin/ldconfig
%endif

%files -n %{name}%{soname}
%defattr(-,root,root)
%{_libdir}/%{name}.so.*

%files widgets%{soname}
%defattr(-,root,root)
%{_libdir}/%{name}-widgets.so.*

%if %{with qt5}
%files qml%{soname}
%defattr(-,root,root)
%{_libdir}/%{name}-qml.so.*
%endif

%files devel
%defattr(-,root,root)
%{_includedir}/%{_name}/
%{_libdir}/%{name}*.so
%{_libdir}/pkgconfig/%{name}*.pc

%files doc
%defattr(-,root,root)
%doc CHANGELOG LICENSE.GPL LICENSE.LGPL
%doc build/html

%changelog
* Sun Nov  8 2015 avvissu@yandex.ru
- Build with qt5 on openSUSE 42.1: add %%%%Leap_verSP
* Fri Apr 24 2015 joerg.lorenzen@ki.tng.de
- Fixed spec file to apply patches and set option WITH_X11 to ON
  for build against qt4.
* Thu Apr 23 2015 avvissu@yandex.ru
- Build with Qt4 for SLE12
* Wed Apr 22 2015 sor.alexei@meowr.ru
- Rename libvlc-qt-0.10.0-fix-file-contains-date-and-time.patch to
  libvlc-qt_no-date-time.patch.
- Rename libvlc-qt_qApp.patch to libvlc-qt_qapplication.patch and
  extend to Qt4.
- Build for 13.1 with Qt4 instead of Qt5: future versions of
  libvlc-qt will support only Qt 5.2+ while building with Qt5.
- Correct license to LGPL-3.0+: upstream sources say "either
  version 3 of the License, or (at your option) any later version".
- Spec cleanup.
* Tue Apr 21 2015 aloisio@gmx.com
- Added libvlc-qt_qApp.patch to fix 13.1 build
* Thu Apr 16 2015 antoine.belvire@laposte.net
- Update to version 0.10.0:
  * Full Qt5 QML support
  * Ability to set VLC plugin path
  * VLC 2.2 support
  * Stats support (issue #28)
  * Debug/Release postfix in library filenames (issue #29)
  * Fix: Make VlcError::errmsg() return QString, not void (issue #48)
  * Fix: Add remaining pkgconfig files (issue #51)
  * See /usr/share/doc/packages/libvlc-qt-doc/CHANGELOG for changes
    introduced with 0.9.0
- Enable parallel build this time
- Remove libvlc-qt-0.8.0-fix-file-contains-date-and-time.patch
- Add libvlc-qt-0.10.0-fix-file-contains-date-and-time.patch
- Clean spec file (see https://en.opensuse.org/openSUSE:Specfile_guidelines)
  * remove Russian translations
  * remove Packager tag
  * add license files and changelog to doc
* Fri Feb 15 2013 svalx@svalx.net
- Updated to version 0.8.0:
  * Separate library into modules: core, widgets and qml
  * Introduce position() and setPosition() methods
  * Fix pause method and introduce togglePause method
  * Removed mouse and fullscreen functions from WidgetVideo
  * Fix: Use proper track ids
  * Fix: Install pkg-config file to correct path (issue #12)
  * Fix: Don't use exit() (issue #13)
- Remove libvlc-qt-0.7.0-define-library-suffix.patch - fixed in upstream.
- Separate package for libvlc-qt-widgets library.
- Disable parallel build - not supported 0.8.0.
* Thu Dec 20 2012 svalx@svalx.net
- Add libvlc-qt-0.7.0-define-library-suffix.patch -- define shared library path suffix if not defined and suffix for pkgconfig
* Wed Dec 19 2012 svalx@svalx.net
- Initial package.
